==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/Transports/http/translations/http_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>HTTPInputFactory</name>
    <message>
        <location filename="../httpinputfactory.cpp" line="33"/>
        <source>HTTP Plugin</source>
        <translation>HTTP Module</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="53"/>
        <source>About HTTP Transport Plugin</source>
        <translation>Over de HTTP Transport Module</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="54"/>
        <source>Qmmp HTTP Transport Plugin</source>
        <translation>HTTP Transport Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="55"/>
        <source>Compiled against libcurl-%1</source>
        <translation>Gecompileerd tegen libcurl-%1</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>HTTP Plugin Settings</source>
        <translation>HTTP Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Buffergrootte:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Metadata encoding</source>
        <translation>Metadata codering</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Automatic charset detection</source>
        <translation>Automatische tekenset detectie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <source>Default encoding:</source>
        <translation>Standaard codering:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="137"/>
        <source>User Agent:</source>
        <translation>Gebruikersagent:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>Change User Agent</source>
        <translation>Gebruikersagent aanpassen</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Transports/http/translations/http_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>HTTPInputFactory</name>
    <message>
        <location filename="../httpinputfactory.cpp" line="34"/>
        <source>HTTP Plugin</source>
        <translation>HTTP Module</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="54"/>
        <source>About HTTP Transport Plugin</source>
        <translation>Over de HTTP Transport Module</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="55"/>
        <source>Qmmp HTTP Transport Plugin</source>
        <translation>HTTP Transport Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="56"/>
        <source>Compiled against libcurl-%1</source>
        <translation>Gecompileerd tegen libcurl-%1</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="57"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>HTTP Plugin Settings</source>
        <translation>HTTP Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Buffergrootte:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Metadata encoding</source>
        <translation>Metadata codering</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Automatic charset detection</source>
        <translation>Automatische tekenset detectie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <source>Default encoding:</source>
        <translation>Standaard codering:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="137"/>
        <source>User Agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>Change User Agent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
